package com.compdfkit.tools.dialog;

import android.content.Context;
import android.text.InputType;
import android.text.TextUtils;

import com.compdfkit.tools.R;

public class GotoPageDialog extends CommonInputDialog {

    private OnGotoPageListener onGotoPageListener = null;

    public GotoPageDialog(Context context) {
        super(context);
        initDialogView();
    }

    public GotoPageDialog(Context context, int theme) {
        super(context, theme);
        initDialogView();
    }

    protected GotoPageDialog(Context context, boolean cancelable, OnCancelListener cancelListener) {
        super(context, cancelable, cancelListener);
        initDialogView();
    }

    public void setTotoPageListener(OnGotoPageListener onGotoPageListener) {
        this.onGotoPageListener = onGotoPageListener;
    }

    private void initDialogView() {
        setTitle(R.string.goto_page_dialog_title);
        setMessage(getContext().getResources().getText(R.string.goto_page_dialog_msg).toString());
        setHintInputText(getContext().getResources().getText(R.string.goto_page_dialog_hint).toString());
        setInputType(InputType.TYPE_CLASS_NUMBER);
        setOkCallback(getContext().getResources().getText(R.string.common_okay).toString(), text -> {
            if (null != onGotoPageListener && (!TextUtils.isEmpty(text))) {
               int page = -1;
               try {
                   page = Integer.parseInt(text);
               } catch (NumberFormatException e) {

               }
                if (page >= 0) {
                    onGotoPageListener.onGotoPage(page);
                }
            }
            dismiss();
        });
        setCancelCallback(getContext().getResources().getText(R.string.common_cancel).toString(), ()-> {
            dismiss();
        });
    }

    public interface OnGotoPageListener {
        public void onGotoPage(int page);
    }
}
