/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfbota.pdfoutline.adapter;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.appcompat.widget.AppCompatImageView;
import androidx.appcompat.widget.AppCompatTextView;
import androidx.recyclerview.widget.RecyclerView;

import com.compdfkit.tools.R;
import com.compdfkit.tools.pdfbota.pdfoutline.bean.COutlineData;
import com.compdfkit.tools.pdfbota.pdfoutline.interfaces.OnOutlineClickListener;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;


public class COutlineListAdapter extends RecyclerView.Adapter<COutlineListAdapter.OutlineItemViewHolder> {

    private List<COutlineData> list = new ArrayList<>();

    private OnOutlineClickListener outlineClickListener;
    public void setList(ArrayList<COutlineData> data){
        list.clear();
        list.addAll(data);
    }


    @NonNull
    @Override
    public OutlineItemViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {

        return new OutlineItemViewHolder(LayoutInflater.from(parent.getContext()).inflate(R.layout.tools_outline_list_item, parent, false));
    }

    @Override
    public void onBindViewHolder(@NonNull OutlineItemViewHolder holder, int position) {
        COutlineData item = list.get(position);
        holder.tvItemPadding.setText(item.getPaddingStr());
        holder.tvItemTitle.setText(item.getTitle());
        holder.tvItemPageIndex.setText(String.valueOf(item.getPageIndex()));
        holder.ivItemArrow.setVisibility(item.childOutlineIsEmpty() ? View.INVISIBLE : View.VISIBLE);
        holder.ivItemArrow.setImageResource(item.isExpand() ? R.drawable.tools_ic_arrow_down : R.drawable.tools_ic_right);

        holder.itemView.setOnClickListener(v -> {
            if (item.childOutlineIsEmpty()){
                if (outlineClickListener != null) {
                    outlineClickListener.callback(item.getPageIndex());
                }
            }else {
                if (item.isExpand()){
                    collapseItem(item);
                }else {
                    expandItem(position, item);
                }
            }
        });
    }

    private void expandItem(int startIndex, COutlineData item){
        item.setExpand(true);
        list.addAll(startIndex +1, item.getChildOutline());
        notifyDataSetChanged();
    }

    private void collapseItem(COutlineData item){
        item.setExpand(false);
        Iterator<COutlineData> iterator = item.getChildOutline().iterator();
        while (iterator.hasNext()){
            list.remove(iterator.next());
        }
        notifyDataSetChanged();
    }

    @Override
    public int getItemCount() {
        return list.size();
    }

    class OutlineItemViewHolder extends RecyclerView.ViewHolder{
        AppCompatTextView tvItemPadding;
        AppCompatImageView ivItemArrow;
        AppCompatTextView tvItemTitle;
        AppCompatTextView tvItemPageIndex;

        public OutlineItemViewHolder(@NonNull View itemView) {
            super(itemView);
            tvItemPadding = itemView.findViewById(R.id.tv_outline_item_padding);
            ivItemArrow = itemView.findViewById(R.id.iv_outline_item_arrow);
            tvItemTitle = itemView.findViewById(R.id.tv_outline_item_title);
            tvItemPageIndex = itemView.findViewById(R.id.tv_outline_item_page);
        }
    }

    public void setOutlineClickListener(OnOutlineClickListener outlineClickListener){
        this.outlineClickListener = outlineClickListener;
    }

}
