/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 * <p>
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.pdfbota.pdfoutline.data;


import com.compdfkit.core.document.CPDFOutline;
import com.compdfkit.tools.pdfbota.pdfoutline.bean.COutlineData;
import com.compdfkit.tools.pdfview.CPDFReaderView;

import java.util.ArrayList;

public class CPDFOutlineDatas {

    /**
     * Get the list of outlines for a PDF document
     * @param cpdfReaderView
     * @see COutlineData
     * @return ArrayList COutlineData
     */
    public static ArrayList<COutlineData> getOutlineList(CPDFReaderView cpdfReaderView) {
        // Retrieve the outline root from the PDF document and convert it to a list of COutlineData objects
        return convertToCOutlineDataList(cpdfReaderView.getCPdfReaderView()
                .getPDFDocument().getOutlineRoot().getChildList());
    }

    /**
     * Recursively convert an array of CPDFOutline objects to an ArrayList of COutlineData objects
     * @param outlines outline list data
     */
    private static ArrayList<COutlineData> convertToCOutlineDataList(CPDFOutline[] outlines) {
        ArrayList<COutlineData> outlineDataList = new ArrayList<>();
        for (CPDFOutline outline : outlines) {
            // Convert the CPDFOutline object to a COutlineData object
            COutlineData outlineData = convertToCOutlineData(outline);
            // Only add the COutlineData object to the list if its level is 1
            if (outlineData.getLevel() == 1) {
                outlineDataList.add(outlineData);
            }
            // If the CPDFOutline object has child outlines, convert them to COutlineData objects and add them to the list
            if (outline.getChildList() != null && outline.getChildList().length > 0) {
                outlineDataList.addAll(convertToCOutlineDataList(outline.getChildList()));
            }
        }
        return outlineDataList;
    }

    /**
     * Convert a CPDFOutline object to a COutlineData object
     */
    private static COutlineData convertToCOutlineData(CPDFOutline outline) {
        COutlineData outlineData = new COutlineData();
        outlineData.setLevel(outline.getLevel());
        outlineData.setPageIndex(outline.getDestination().getPageIndex());
        outlineData.setTitle(outline.getTitle());
        outlineData.setChildOutline(new ArrayList<>());

        // If the CPDFOutline object has child outlines, convert them to COutlineData objects and add them to the list
        if (outline.getChildList() != null && outline.getChildList().length > 0) {
            for (CPDFOutline child : outline.getChildList()) {
                outlineData.getChildOutline().add(convertToCOutlineData(child));
            }
        }

        return outlineData;
    }

}
